import { useState, useEffect } from 'react';
import { csv, timeParse } from 'd3';

//const csvUrl =
//  'https://raw.githubusercontent.com/CSSEGISandData/COVID-19/master/csse_covid_19_data/csse_covid_19_time_series/time_series_covid19_deaths_global.csv';

const csvUrl =  'https://raw.githubusercontent.com/CSSEGISandData/COVID-19/d1ed7ef35690594a918ed5fe1ffb6a75266d2c1f/csse_covid_19_data/csse_covid_19_time_series/time_series_covid19_deaths_global.csv';


const sum = (accumulator, currentValue) =>
  accumulator + currentValue;

const parseDay = timeParse('%m/%d/%y');

// get timeseries data for each country
const transform = (rawData) => {
  const countriesData = rawData.filter(
    (d) => !d['Province/State']
  );
  const days = rawData.columns.slice(4);
  return countriesData.map((d) => {
    const countryName = d['Country/Region'];
    const countryTimeSeries =  days.map((day) => ({
      date: parseDay(day),
      deathTotal: +d[day],
      countryName
    }));
  	countryTimeSeries.countryName = countryName;
    return countryTimeSeries;
    
  });
};

export const useData = () => {
  const [data, setData] = useState();

  useEffect(() => {
    csv(csvUrl).then((rawData) => {
      setData(transform(rawData));
    });
    
  console.log(data);
  }, []);

  return data;
};
